==> docusign-admin-java-1.3.0-sources.jar: com/docusign/admin/model/OrganizationExportDomain.java <==
package com.docusign.admin.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Objects;

/** OrganizationExportDomain. */
public class OrganizationExportDomain {
  @JsonProperty("domain")
  private String domain = null;

  /**
   * domain.
   *
   * @return OrganizationExportDomain
   */
  public OrganizationExportDomain domain(String domain) {
    this.domain = domain;
    return this;
  }

  /**
   * Get domain.
   *
   * @return domain
   */
  @Schema(description = "")
  public String getDomain() {
    return domain;
  }

  /** setDomain. */
  public void setDomain(String domain) {
    this.domain = domain;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    OrganizationExportDomain organizationExportDomain = (OrganizationExportDomain) o;
    return Objects.equals(this.domain, organizationExportDomain.domain);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(domain);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class OrganizationExportDomain {\n");

    sb.append("    domain: ").append(toIndentedString(domain)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-admin-java-2.0.0-sources.jar: com/docusign/admin/model/OrganizationExportDomain.java <==
package com.docusign.admin.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;

/** OrganizationExportDomain. */
public class OrganizationExportDomain implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("domain")
  private String domain = null;

  /**
   * domain.
   *
   * @return OrganizationExportDomain
   */
  public OrganizationExportDomain domain(String domain) {
    this.domain = domain;
    return this;
  }

  /**
   * Get domain.
   *
   * @return domain
   */
  @Schema(description = "")
  public String getDomain() {
    return domain;
  }

  /** setDomain. */
  public void setDomain(String domain) {
    this.domain = domain;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    OrganizationExportDomain organizationExportDomain = (OrganizationExportDomain) o;
    return Objects.equals(this.domain, organizationExportDomain.domain);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(domain);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class OrganizationExportDomain {\n");

    sb.append("    domain: ").append(toIndentedString(domain)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
